@@ -1,7 +1,7 @@
 # --------------------------------------------------------------- Imports ---------------------------------------------------------------- #
 
 # System
-from typing import List, Dict, Optional
+from typing import List, Dict, Optional, Tuple
 import time, json
 
 # Pip
@@ -46,10 +46,11 @@ class Youtube:
         password: Optional[str] = None,
         host: Optional[str] = None,
         port: Optional[int] = None,
+        screen_size: Optional[Tuple[int, int]] = None,
         full_screen: bool = False,
         disable_images: bool = False
     ):
-        self.browser = Firefox(cookies_folder_path, extensions_folder_path, host=host, port=port, full_screen=full_screen, disable_images=disable_images)
+        self.browser = Firefox(cookies_folder_path, extensions_folder_path, host=host, port=port, screen_size=screen_size, full_screen=full_screen, disable_images=disable_images)
         self.channel_id = None
 
         try:
@@ -116,8 +117,8 @@ class Youtube:
                 with timeout.timeout(_timeout):
                     return self.__upload(video_path, title, description, tags, extra_sleep_after_upload=extra_sleep_after_upload)
             except Exception as e:
-                print(e)
-                self.browser.get(YT_URL)
+                print('Upload', e)
+                # self.browser.get(YT_URL)
 
                 return False, None
         else:
@@ -133,7 +134,7 @@ class Youtube:
                 ) + '}'
             )['responseContext']['serviceTrackingParams'][2]['params'][0]['value']
         except Exception as e:
-            print(e)
+            print('get_current_channel_id', e)
 
             return None
 
@@ -152,8 +153,8 @@ class Youtube:
                 with timeout.timeout(_timeout):
                     return self.__comment_on_video(video_id, comment, pinned=pinned)
             except Exception as e:
-                print(e)
-                self.browser.get(YT_URL)
+                print('Comment', e)
+                # self.browser.get(YT_URL)
 
                 return False, False
         else:
